Module lets_be_rational
quant_
opts
0.1.0
Module lets_
be_
rational
Module Items
Functions
In crate quant_
opts
quant_opts
Module
lets_
be_
rational
Functions

black
Calculates the price of a European option using the Black model.
implied_
volatility_
from_
a_
transformed_
rational_
guess
Calculates the implied volatility of an option using a rational guess.